<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2009 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2009 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.1 2009/01/11 05:34:30 seasonstream Exp $
 * @link      http://syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * 管理フローの基底クラス
 */
require_once SYL_FRAMEWORK_DIR . '/core/Adm/SyL_AdmFlow.php';

/**
 * 管理フロー詳細表示クラス
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2009 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.1 2009/01/11 05:34:30 seasonstream Exp $
 * @link      http://syl.jp/
 */
class SyL_AdmFlowVew extends SyL_AdmFlow
{
    /**
     * オペレーション名
     *
     * @access protected
     * @var string
     */
    var $opp_name = 'vew';

    /**
     * コンストラクタ
     *
     * @access public
     */
    function SyL_AdmFlowVew()
    {
        parent::SyL_AdmFlow();
    }

    /**
     * 詳細表示フロー
     *
     * @access public
     * @param object データ管理オブジェクト
     * @param object コンテキスト管理オブジェクト
     */
    function execute(&$data, &$context)
    {
        // フォーム取得
        $form =& $this->getForm();
        // 主キーパラメータ名取得
        $key_name = $form->getStructConfig('key_name');
        // パラメータ取得
        $key = $data->get($key_name);
        if (($key === null) || ($key === '')) {
            SyL_Error::trigger("[Adm error] Key parameter not found");
        }

        // DB接続取得
        $conn =& $context->getDB();
        // ADMオブジェクト作成
        $adm  =& SyL_Adm::factory($form, $conn, array($key));
        // テーブル情報ロード
        $adm->loadConfig();
        // アクセス権チェック
        if (!$adm->isVew()) {
            // アクセス権限なし
            SyL_Error::trigger("[Adm error] View Opperation Forbidden");
        }
        // 詳細表示データ取得
        $result = $adm->getRecord();
        if (!$result) {
            SyL_Response::redirect($this->getUrl($context, 'lst'));
        }
        // 既存データセット
        $data->sets($result);
        // データ取得オブジェクトセット
        $form->registerInput($data);
        // フォーム構築
        $form->build();
        // 表示のみ
        $form->setReadOnly(true);

        // DB接続終了
        $context->closeDB($conn);

        // フォーム要素データ
        $data->set('form', $form->getResultArray());
        // 主キーパラメータ
        $data->set('key_name',  $key_name);
        $data->set('key_value', $adm->getKeyQuery());
        //$data->set('key_array', $adm->getKey());

        // 確認表示関連
        $data->set('view_alert', $form->getStructConfig('view_alert'));
        // 文言関連
        $data->set('title', $form->getStructConfig('title'));

        // リンク先URL
        $data->set('url_lst', $this->getUrl($context, 'lst'));
        $data->set('url_upd', $this->getUrl($context, 'upd'));
        $data->set('url_del', $this->getUrl($context, 'del'));
        $data->set('url_dir', dirname($context->getScriptName()));

        // 編集可能フラグ
        $data->set('enable_upd', $adm->isUpd());
        // 削除可能フラグ
        $data->set('enable_del', $adm->isDel());

        // 関連リンク
        //$data->set('related_links', $form->getRelatedLinks());
    }

}
