<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2009 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2009 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_WebServiceJlpDAServiceSearchRequest.php,v 1.1 2009/01/11 05:34:34 seasonstream Exp $
 * @link      http://syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * WEBサービスレスポンスクラス（Yahoo! Japan - 指定形容詞係り先検索Webサービス）
 */
require_once 'SyL_WebServiceJlpDAServiceSearchResponse.php';

/**
 * WEBサービスリクエストクラス（Yahoo! Japan - 指定形容詞係り先検索Webサービス）
 *
 * 詳細は、Yahoo!デベロッパーネットワーク参照
 *   http://developer.yahoo.co.jp/
 * 指定形容詞係り先検索Webサービス
 *   http://developer.yahoo.co.jp/jlp/DAServiceSearch/V1/search.html
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2009 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_WebServiceJlpDAServiceSearchRequest.php,v 1.1 2009/01/11 05:34:34 seasonstream Exp $
 * @link      http://syl.jp/
 */
class SyL_WebServiceJlpDAServiceSearchRequest extends SyL_WebServiceYahoo_co_jpRequest
{
    /**
     * WEBサービスサーバーのホスト名
     *
     * @access protected
     * @var string
     */
    var $host = 'jlp.yahooapis.jp';
    /**
     * 実行URLパス
     *
     * @access protected
     * @var string
     */
    var $path = '/DAServiceSearch/V1/search';
    /**
     * レスポンスクラス名
     *
     * @access protected
     * @var string
     */
    var $response_class = 'SyL_WebServiceJlpDAServiceSearchResponse';

    /**
     * 解析対象のテキストをセットする
     *
     * @access public
     * @param string 解析対象のテキスト
     */
    function setSentence($sentence)
    {
        parent::set('sentence', $sentence);
    }

    /**
     * 指定した形容詞の係る単語をセットする
     *
     * @access public
     * @param string 指定した形容詞の係る単語
     */
    function setMode($mode)
    {
        if (!preg_match('/^[1-8]$/', $mode)) {
            trigger_error("[SyL error] Invalid `mode' property ({$mode}) in `" . __CLASS__ . "' class", E_USER_ERROR);
        }
        parent::set('mode', $mode);
    }
}
